document.addEventListener('DOMContentLoaded', () => {
  const shortenBtn = document.getElementById('shortenBtn');
  const urlInput = document.getElementById('urlInput');
  const resultArea = document.getElementById('resultArea');

  shortenBtn.addEventListener('click', () => {
    const url = urlInput.value;
    if (!url) {
      showError('Please enter a URL');
      return;
    }
    if (!isValidUrl(url)) {
      showError('Please enter a valid URL');
      return;
    }
    
    // Simulate API call
    simulateShortening(url);
  });

  function isValidUrl(string) {
    try {
      new URL(string);
      return true;
    } catch (_) {
      return false;
    }
  }

  function showError(message) {
    resultArea.innerHTML = `<p style="color: #ef4444;">${message}</p>`;
  }

  function simulateShortening(url) {
    shortenBtn.disabled = true;
    shortenBtn.textContent = 'Processing...';
    
    setTimeout(() => {
      const shortUrl = `link.scroll.pub/${generateShortCode()}`;
      resultArea.innerHTML = `
        <div style="margin-top: 1rem;">
          <p style="color: #059669;">Success! Your shortened URL:</p>
          <a href="https://${shortUrl}" style="color: #6366f1; text-decoration: none;">
            ${shortUrl}
          </a>
          <button onclick="navigator.clipboard.writeText('https://${shortUrl}')" 
                  style="background: none; border: none; color: #6366f1; cursor: pointer; margin-left: 0.5rem;">
            📋
          </button>
        </div>
      `;
      shortenBtn.disabled = false;
      shortenBtn.textContent = 'Shorten';
    }, 1000);
  }

  function generateShortCode() {
    const chars = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
    return Array.from({length: 6}, () => chars.charAt(Math.floor(Math.random() * chars.length))).join('');
  }

  // Add smooth scrolling
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });
});